Discovery Service
=================

Minos API Gateway Discovery Service

Credits
-------

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter)  and the [Minos Package](https://github.com/Clariteia/minos-pypackage) project template.
